package com.ichaoj.ams.controller;

import cn.hutool.core.bean.BeanUtil;
import com.ichaoj.ams.entity.AmsStrategy;
import com.ichaoj.ams.request.strategy.CreateStrategy;
import com.ichaoj.ams.request.strategy.UpdateStrategy;
import com.ichaoj.ams.service.IAmsStrategyService;
import com.ichaoj.common.annotation.AuthResource;
import com.ichaoj.common.model.PublicResult;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * <p>
 * 策略管理 前端控制器
 * </p>
 *
 * @author cjwen
 * @since 2023-04-25
 */
@RestController
@RequestMapping("/strategy")
@Tag(name = "策略模块")
public class StrategyController {

    @Resource
    private IAmsStrategyService strategyService;

    @PostMapping
    @Operation(summary = "创建策略")
    @AuthResource(true)
    public PublicResult<Object> createStrategy(@RequestBody CreateStrategy createStrategy) {
        strategyService.save(BeanUtil.copyProperties(createStrategy, AmsStrategy.class));
        return PublicResult.success();
    }

    @PutMapping
    @Operation(summary = "修改策略")
    @AuthResource(true)
    public PublicResult<Object> updateAuto(@RequestBody @Validated UpdateStrategy updateStrategy) {
        strategyService.updateById(BeanUtil.copyProperties(updateStrategy, AmsStrategy.class));
        return PublicResult.success();
    }

    @DeleteMapping("/{strategyId}")
    @Operation(summary = "删除策略")
    @AuthResource(true)
    public PublicResult<Object> deleteAirdropProject(@PathVariable String strategyId) {
        strategyService.removeById(strategyId);
        return PublicResult.success();
    }

}
